@@ -27,7 +27,9 @@ except ImportError:
 
 
 class MailChimpError(Exception):
-    pass
+    def __init__(self, msg, code):
+        self.msg = msg
+        self.code = code
 
 
 class MailChimp(object):
@@ -62,7 +64,7 @@ class MailChimp(object):
             response = json.loads(handle.read())
             try:
                 if 'error' in response:
-                    raise MailChimpError(response['error'])
+                    raise MailChimpError(response['error'], response['code'])
             except TypeError: # the response was boolean
                 pass
             return response
